@@ -7,8 +7,6 @@
 ##   - univention-directory-manager-tools
 ## packages-not:
 ##   - univention-ad-connector
-## bugs:
-##   - 56999
 
 
 import base64
@@ -95,7 +93,7 @@ def blocklist_setup(random_string, udm):
             'users/user mobileTelephoneNumber',
             'users/user pagerTelephoneNumber',
             'users/user homePostalAddress',
-        ]
+        ],
     }
     udm.create_object('blocklists/list', **data)
 
@@ -129,6 +127,6 @@ def test_create_1000_users_with_extreme_blocklist_setup(mail_domain_name):
             lo.delete(dn)
     duration = end - start
     if package_installed('univention-samba4'):
-        assert duration < 3000  # FXIME: hard coded performance timeout sucks
+        assert duration < 300
     else:
-        assert duration < 2500  # FXIME: hard coded performance timeout sucks
+        assert duration < 250
