@@ -26,7 +26,7 @@ class TestPwdChangeNextLogin:
     """
     Ensure that the UMC PAM configuration for pam_unix.so + pam_krb5.so is correct.
     This is tested by UMC authenticating a user with pwdChangeNextLogin=1
-    pam_ldap is therefore untested!
+    pam_sss is therefore untested!
     """
 
     PWD_CHANGE_NEXT_LOGIN_OPTIONS = [
@@ -53,6 +53,10 @@ class TestPwdChangeNextLogin:
 
         udm.modify_object('users/user', dn=userdn, pwdChangeNextLogin=1)
 
+        if samba4_installed:
+            utils.wait_for_connector_replication()
+            wait_for_drs_replication(filter_format('(&(sAMAccountName=%s)(pwdLastSet=0))', [username]))
+            utils.wait_for_s4connector_replication()
         client = Client(language='en-US')
         with pytest.raises(Unauthorized) as msg:
             client.authenticate(username, password)
@@ -88,10 +92,10 @@ class TestPwdChangeNextLogin:
         if samba4_installed:
             utils.wait_for_connector_replication()
             wait_for_drs_replication(filter_format('(&(sAMAccountName=%s)(!(pwdLastSet=0)))', [username]))
-            # fails on backup because the user account in the local ldap has still shadowMax=1 (or 0 since Bug #57681)
+            # fails on backup because the user account in the local ldap has still shadowMax=1
             # we set the password via krb5 -> samba, now drs replication to the master, s4 connector
             # on the master and LDAP replication to the backup, no way to wait for that
-            # best would be to check the local ldap backup for NOT shadowMax=1 (0 since Bug #57681), but sleep also works for now
+            # best would be to check the local ldap backup for NOT shadowMax=1, but sleep also works for now
             time.sleep(30)
 
         print('check login with new password')
@@ -127,7 +131,7 @@ class TestBasics:
 
 
 class TestLDAPUsers:
-    """Ensure pam_ldap.so works and the PAM configuration for LDAP users is not disturbed by pam_unix.so / pam_ldap.so)"""
+    """Ensure pam_sss.so works and the PAM configuration for LDAP users is not disturbed by pam_unix.so / pam_sss.so)"""
 
     def test_ldap_pwd_user_umc_authentication(self, udm, Client, random_string):
         password = random_string()
