@@ -8,7 +8,6 @@
 
 import re
 import time
-from typing import Dict, Union
 
 import pytest
 from playwright.sync_api import Locator, Page, expect
@@ -20,7 +19,7 @@ from univention.testing.browser.selfservice import SelfService
 from univention.testing.strings import random_username
 
 
-@pytest.fixture(autouse=True)
+@pytest.fixture(autouse=True, scope='session')
 def activate_self_service(ucr_session):
     ucr_session.handler_set(
         [
@@ -43,12 +42,12 @@ def self_service_user(udm_module_scope) -> SelfServiceUser:
     return do_create_user(udm_module_scope, mailPrimaryAddress=reset_mail_address, language='en-US')
 
 
-def find_label(page: Page, label_display_text: str) -> Union[Locator, None]:
+def find_label(page: Page, label_display_text: str) -> Locator | None:
     label_display_locators = page.get_by_text(label_display_text).all()
     return next((label_display_locator for label_display_locator in label_display_locators if label_display_locator.evaluate('(element) => element.tagName') == 'LABEL'), None)
 
 
-def check_labels(page: Page, labels: Dict[str, str], retries=4):
+def check_labels(page: Page, labels: dict[str, str], retries=4):
     for label_display, label_tag in labels.items():
         for i in range(retries):
             logger.info("checking for label with text %r and with attribute 'for=%r' (%d/%d)", label_display, label_tag, i + 1, retries)
@@ -57,7 +56,8 @@ def check_labels(page: Page, labels: Dict[str, str], retries=4):
                 assert found_label is not None, f'A label with the text {label_display} has not been found.'
                 expect(found_label).to_be_visible()
                 expect(found_label, f"Expected locator to have tag {label_tag}--\\d\\d, but found {found_label.get_attribute('for')}").to_have_attribute(
-                    'for', re.compile(rf'{label_tag}--\d\d')
+                    'for',
+                    re.compile(rf'{label_tag}--\d\d'),
                 )
                 return
             except AssertionError:
@@ -93,7 +93,7 @@ def check_labels(page: Page, labels: Dict[str, str], retries=4):
         (UCSLanguage.DE_DE, 'servicespecificpasswords', {'Benutzername': 'username', 'Passwort': 'password'}),
     ],
 )
-def test_frontend_translations(self_service: SelfService, lang: UCSLanguage, hash: str, labels: Dict[str, str]):
+def test_frontend_translations(self_service: SelfService, lang: UCSLanguage, hash: str, labels: dict[str, str]):
     page: Page = self_service.tester.page
     self_service.tester.set_language(lang)
     self_service.navigate(hash)
@@ -151,7 +151,7 @@ def test_frontend_translations(self_service: SelfService, lang: UCSLanguage, has
         (UCSLanguage.DE_DE, 'servicespecificpasswords', {'Benutzername': 'username', 'Passwort': 'password'}),
     ],
 )
-def test_frontend_login_translations(self_service: SelfService, lang: UCSLanguage, hash: str, labels: Dict[str, str], self_service_user):
+def test_frontend_login_translations(self_service: SelfService, lang: UCSLanguage, hash: str, labels: dict[str, str], self_service_user):
     page: Page = self_service.tester.page
     self_service.tester.set_language(lang)
     self_service.navigate(hash, username=self_service_user.username, password=self_service_user.password)
