@@ -1,3 +1,9 @@
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
 """Format UCS Test results as JUnit report."""
 
 
@@ -128,7 +134,7 @@ class Junit(TestFormatInterface):
 
             if skipped:
                 try:
-                    mime, content = result.artifacts['check']
+                    _mime, content = result.artifacts['check']
                 except KeyError:
                     msg = ''
                 else:
@@ -151,7 +157,7 @@ class Junit(TestFormatInterface):
                 xml.endElement('failure')
 
             try:
-                mime, content = result.artifacts['stdout']
+                _mime, content = result.artifacts['stdout']
             except KeyError:
                 pass
             else:
@@ -160,7 +166,7 @@ class Junit(TestFormatInterface):
                 xml.endElement('system-out')
 
             try:
-                mime, content = result.artifacts['stderr']
+                _mime, content = result.artifacts['stderr']
             except KeyError:
                 pass
             else:
