@@ -41,8 +41,7 @@ import time
 import traceback
 from enum import IntEnum
 from itertools import chain
-from types import TracebackType
-from typing import IO, Any, Callable, Dict, Iterable, List, Mapping, NoReturn, Sequence, Tuple, Type, TypeVar
+from typing import IO, TYPE_CHECKING, Any, NoReturn, TypeVar
 
 import ldap
 
@@ -50,6 +49,11 @@ from univention import uldap
 from univention.config_registry import ConfigRegistry
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable, Mapping, Sequence
+    from types import TracebackType
+
+
 try:
     from univention.admin.uldap import access
 except ImportError:
@@ -62,7 +66,7 @@ SLAPD_INIT_SCRIPT = '/etc/init.d/slapd'
 UCR = ConfigRegistry()
 
 
-_T = TypeVar("_T")  # noqa: PYI018
+_T = TypeVar("_T")
 
 
 class LDAPError(Exception):
@@ -149,7 +153,7 @@ def get_ldap_connection(admin_uldap: bool = False, primary: bool = False) -> acc
     raise ldap.SERVER_DOWN()
 
 
-def retry_on_error(func: Callable[..., _T], exceptions: Tuple[Type[Exception], ...] = (Exception,), retry_count: int = 20, delay: float = 10) -> _T:
+def retry_on_error(func: Callable[..., _T], exceptions: tuple[type[Exception], ...] = (Exception,), retry_count: int = 20, delay: float = 10) -> _T:
     """
     This function calls the given function `func`.
     If one of the specified `exceptions` is caught, `func` is called again until
@@ -186,8 +190,8 @@ def verify_ldap_object(
         delay: float = 10,
         primary: bool = False,
         pre_check: Callable[..., None] | None = None,
-        pre_check_kwargs: Dict[str, Any] | None = None,
-        not_expected_attr: Dict[str, str] | None = None,
+        pre_check_kwargs: dict[str, Any] | None = None,
+        not_expected_attr: dict[str, str] | None = None,
 ) -> None:
     """
     Verify [non]existence and attributes of LDAP object.
@@ -232,7 +236,7 @@ def __verify_ldap_object(
         strict: bool = True,
         should_exist: bool = True,
         primary: bool = False,
-        not_expected_attr: Dict[str, str] | None = None,
+        not_expected_attr: dict[str, str] | None = None,
 ) -> None:
     if expected_attr is None:
         expected_attr = {}
@@ -369,7 +373,7 @@ class AutomaticListenerRestart:
     def __enter__(self) -> AutomaticListenerRestart:  # FIXME Py3.9: Self
         return self
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         restart_listener()
 
 
@@ -410,7 +414,7 @@ class AutoCallCommand:
             subprocess.call(self.enter_cmd, stdout=self.pipe_stdout, stderr=self.pipe_stderr)
         return self
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         if self.exit_cmd:
             subprocess.call(self.exit_cmd, stdout=self.pipe_stdout, stderr=self.pipe_stderr)
 
@@ -440,13 +444,13 @@ class FollowLogfile:
         """
         assert isinstance(always, bool)
         self.always = always
-        self.logfile_pos: Dict[str, int] = dict.fromkeys(logfiles, 0)
+        self.logfile_pos: dict[str, int] = dict.fromkeys(logfiles, 0)
 
     def __enter__(self) -> FollowLogfile:  # FIXME Py3.9: Self
         self.logfile_pos.update((logfile, os.path.getsize(logfile)) for logfile in self.logfile_pos)
         return self
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         if self.always or exc_type:
             for logfile, pos in self.logfile_pos.items():
                 with open(logfile) as log:
@@ -467,7 +471,7 @@ class ReplicationType(IntEnum):
 def wait_for_replication_from_master_openldap_to_local_samba(replication_postrun: bool = False, ldap_filter: str | None = None, verbose: bool = True) -> None:
     """Wait for all kind of replications"""
     # the order matters!
-    conditions: List[Tuple[ReplicationType, Any]] = [(ReplicationType.LISTENER, 'postrun' if replication_postrun else True)]
+    conditions: list[tuple[ReplicationType, Any]] = [(ReplicationType.LISTENER, 'postrun' if replication_postrun else True)]
     ucr = UCR
     ucr.load()
     if ucr.get('samba4/ldap/base'):
@@ -494,7 +498,7 @@ def wait_for_replication_from_local_samba_to_local_openldap(replication_postrun:
     wait_for(conditions, verbose=True)
 
 
-def wait_for(conditions: List[Tuple[ReplicationType, Any]] | None = None, verbose: bool = True) -> None:
+def wait_for(conditions: list[tuple[ReplicationType, Any]] | None = None, verbose: bool = True) -> None:
     """Wait for all kind of replications"""
     for replicationtype, detail in conditions or []:
         if replicationtype == ReplicationType.LISTENER:
@@ -565,10 +569,11 @@ def wait_for_listener_replication_and_postrun(verbose: bool = True) -> None:
             seconds_since_last_change += 1
         else:
             seconds_since_last_change = 0
+
+        # Less than 15 sec because a postrun function can potentially make ldap changes,
+        # which would result in a loop here.
         if seconds_since_last_change > 12:
-            # Less than 15 sec because a postrun function can potentially make ldap changes,
-            # which would result in a loop here.
-            time.sleep(10)  # Give the postrun function some time
+            time.sleep(20)  # Give the postrun function some time
             if verbose:
                 print("Postrun should have run")
             return
@@ -658,6 +663,28 @@ def is_port_open(port: int, hosts: Iterable[str] | None = None, timeout: float =
     return False
 
 
+def no_change_in_file(no_change_for: int, log_file: str) -> bool:
+    modify_time = os.path.getmtime(log_file)
+    current_time = time.time()
+    if (current_time - modify_time) >= no_change_for:
+        return True
+    return False
+
+
+def wait_for_s4_connector_to_be_inactive(no_change_for: int = 10) -> None:
+    log_file = '/var/log/univention/connector-s4.log'
+    if not os.path.isfile(log_file):
+        return
+    for i in range(30):
+        if no_change_in_file(no_change_for, log_file):
+            print(f'no change in {log_file} for {no_change_for}s')
+            break
+        print('connector is active, waiting')
+        time.sleep(no_change_for + 3)
+    else:
+        print('wait_for_s4_connector_to_be_inactive timed out, contiuing anyway')
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
